        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 16 <br>2,3,7,10,11,14,17,19,23,25,29,30,31,32,45,46';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 14 <strong>control</strong><br>0,1,8,12,13,18,20,21,22,27,34,41,44,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>4,6,9,24,28,36,38,39,40,42,47,50';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 9 <br>5,15,16,26,33,35,37,43,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 16 <br>2,3,7,10,11,14,17,19,23,25,29,30,31,32,45,46';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 14 <strong>control</strong><br>0,1,8,12,13,18,20,21,22,27,34,41,44,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>4,6,9,24,28,36,38,39,40,42,47,50';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 9 <br>5,15,16,26,33,35,37,43,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 16 <br>2,3,7,10,11,14,17,19,23,25,29,30,31,32,45,46';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 14 <strong>control</strong><br>0,1,8,12,13,18,20,21,22,27,34,41,44,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>4,6,9,24,28,36,38,39,40,42,47,50';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 9 <br>5,15,16,26,33,35,37,43,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 16 <br>2,3,7,10,11,14,17,19,23,25,29,30,31,32,45,46';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 14 <strong>control</strong><br>0,1,8,12,13,18,20,21,22,27,34,41,44,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>4,6,9,24,28,36,38,39,40,42,47,50';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 9 <br>5,15,16,26,33,35,37,43,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 16 <br>2,3,7,10,11,14,17,19,23,25,29,30,31,32,45,46';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 14 <strong>control</strong><br>0,1,8,12,13,18,20,21,22,27,34,41,44,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>4,6,9,24,28,36,38,39,40,42,47,50';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 9 <br>5,15,16,26,33,35,37,43,48';}
}
